PO Files — Translate Toolkit 1.9.0 documentation

# PO Files

PO files use the file format of the Gettext tools.

See also

Gettext manual and KDE style PO files

## Supported Features

- Headers
- Plural forms and plural form handling
- Obsolete messages
- Message Context (msgctxt)
- Language header (since gettext version 0.17)
- Previous message ID and context (#| msgid and #| msgctxt)

## Supported comments

- normal comments

    # this is another comment

- automatic comments

    #. comment extracted from the source code

- source location comments

    #: sourcefile.xxx:35

- typecomments

    #, fuzzy

- msgidcomments

    msgid "_: comment\n"
    "translation"

Also know as KDE style comments as they are used by KDE for message disambiguation and comments to translators. (support for this is being phased out)

- obsolete messages

    #~ msgid "Blah"
    #~ msgstr "Bleeh"

- previous msgid and msgctxt

    #| msgid "previous message"

## Unsupported Features

None